Documentation
¶
Overview ¶
Package mocks is a generated GoMock package.
Index ¶
- type MockAPIClient
- func (m *MockAPIClient) EXPECT() *MockAPIClientMockRecorder
- func (m *MockAPIClient) GetDefaultBranch(ctx context.Context, owner, repo string) (string, error)
- func (m *MockAPIClient) GetRateLimit(ctx context.Context) (*github.RateLimit, error)
- func (m *MockAPIClient) GetRepository(ctx context.Context, owner, repo string) (*github.RepositoryInfo, error)
- func (m *MockAPIClient) GetRepositoryConfiguration(ctx context.Context, owner, repo string) (*github.RepositoryConfig, error)
- func (m *MockAPIClient) ListOrganizationRepositories(ctx context.Context, org string) ([]github.RepositoryInfo, error)
- func (m *MockAPIClient) SetToken(ctx context.Context, token string) error
- func (m *MockAPIClient) UpdateRepositoryConfiguration(ctx context.Context, owner, repo string, config *github.RepositoryConfig) error
- type MockAPIClientMockRecorder
- func (mr *MockAPIClientMockRecorder) GetDefaultBranch(ctx, owner, repo any) *gomock.Call
- func (mr *MockAPIClientMockRecorder) GetRateLimit(ctx any) *gomock.Call
- func (mr *MockAPIClientMockRecorder) GetRepository(ctx, owner, repo any) *gomock.Call
- func (mr *MockAPIClientMockRecorder) GetRepositoryConfiguration(ctx, owner, repo any) *gomock.Call
- func (mr *MockAPIClientMockRecorder) ListOrganizationRepositories(ctx, org any) *gomock.Call
- func (mr *MockAPIClientMockRecorder) SetToken(ctx, token any) *gomock.Call
- func (mr *MockAPIClientMockRecorder) UpdateRepositoryConfiguration(ctx, owner, repo, config any) *gomock.Call
- type MockChangeLoggerInterface
- func (m *MockChangeLoggerInterface) EXPECT() *MockChangeLoggerInterfaceMockRecorder
- func (m *MockChangeLoggerInterface) GetOperationHistory(ctx context.Context, filters github.LogFilters) ([]github.LogOperationRecord, error)
- func (m *MockChangeLoggerInterface) LogOperation(ctx context.Context, operation github.LogOperationRecord) error
- func (m *MockChangeLoggerInterface) SetLogLevel(ctx context.Context, level github.LogLevelType) error
- type MockChangeLoggerInterfaceMockRecorder
- type MockCloneService
- func (m *MockCloneService) CloneOrganization(ctx context.Context, orgName, targetPath, strategy string) error
- func (m *MockCloneService) CloneRepository(ctx context.Context, repo github.RepositoryInfo, targetPath, strategy string) error
- func (m *MockCloneService) EXPECT() *MockCloneServiceMockRecorder
- func (m *MockCloneService) GetSupportedStrategies(ctx context.Context) ([]string, error)
- func (m *MockCloneService) RefreshAll(ctx context.Context, targetPath, orgName, strategy string) error
- func (m *MockCloneService) SetStrategy(ctx context.Context, strategy string) error
- type MockCloneServiceMockRecorder
- func (mr *MockCloneServiceMockRecorder) CloneOrganization(ctx, orgName, targetPath, strategy any) *gomock.Call
- func (mr *MockCloneServiceMockRecorder) CloneRepository(ctx, repo, targetPath, strategy any) *gomock.Call
- func (mr *MockCloneServiceMockRecorder) GetSupportedStrategies(ctx any) *gomock.Call
- func (mr *MockCloneServiceMockRecorder) RefreshAll(ctx, targetPath, orgName, strategy any) *gomock.Call
- func (mr *MockCloneServiceMockRecorder) SetStrategy(ctx, strategy any) *gomock.Call
- type MockConfirmationServiceInterface
- func (m *MockConfirmationServiceInterface) ConfirmBulkOperation(ctx context.Context, operations []github.OperationRecord) ([]bool, error)
- func (m *MockConfirmationServiceInterface) ConfirmOperation(ctx context.Context, prompt *github.ConfirmationPromptRecord) (bool, error)
- func (m *MockConfirmationServiceInterface) EXPECT() *MockConfirmationServiceInterfaceMockRecorder
- func (m *MockConfirmationServiceInterface) SetConfirmationMode(ctx context.Context, mode github.ConfirmationModeType) error
- type MockConfirmationServiceInterfaceMockRecorder
- func (mr *MockConfirmationServiceInterfaceMockRecorder) ConfirmBulkOperation(ctx, operations any) *gomock.Call
- func (mr *MockConfirmationServiceInterfaceMockRecorder) ConfirmOperation(ctx, prompt any) *gomock.Call
- func (mr *MockConfirmationServiceInterfaceMockRecorder) SetConfirmationMode(ctx, mode any) *gomock.Call
- type MockGitHubService
- func (m *MockGitHubService) CloneOrganization(ctx context.Context, orgName, targetPath, strategy string) error
- func (m *MockGitHubService) CloneRepository(ctx context.Context, repo github.RepositoryInfo, targetPath, strategy string) error
- func (m *MockGitHubService) ConfirmBulkOperation(ctx context.Context, operations []github.OperationRecord) ([]bool, error)
- func (m *MockGitHubService) ConfirmOperation(ctx context.Context, prompt *github.ConfirmationPromptRecord) (bool, error)
- func (m *MockGitHubService) EXPECT() *MockGitHubServiceMockRecorder
- func (m *MockGitHubService) GetDefaultBranch(ctx context.Context, owner, repo string) (string, error)
- func (m *MockGitHubService) GetOperationHistory(ctx context.Context, filters github.LogFilters) ([]github.LogOperationRecord, error)
- func (m *MockGitHubService) GetRateLimit(ctx context.Context) (*github.RateLimit, error)
- func (m *MockGitHubService) GetRepository(ctx context.Context, owner, repo string) (*github.RepositoryInfo, error)
- func (m *MockGitHubService) GetRepositoryConfiguration(ctx context.Context, owner, repo string) (*github.RepositoryConfig, error)
- func (m *MockGitHubService) GetRequiredScopes(ctx context.Context, operation string) ([]string, error)
- func (m *MockGitHubService) GetSupportedStrategies(ctx context.Context) ([]string, error)
- func (m *MockGitHubService) ListOrganizationRepositories(ctx context.Context, org string) ([]github.RepositoryInfo, error)
- func (m *MockGitHubService) LogOperation(ctx context.Context, operation github.LogOperationRecord) error
- func (m *MockGitHubService) RefreshAll(ctx context.Context, targetPath, orgName, strategy string) error
- func (m *MockGitHubService) SetConfirmationMode(ctx context.Context, mode github.ConfirmationModeType) error
- func (m *MockGitHubService) SetLogLevel(ctx context.Context, level github.LogLevelType) error
- func (m *MockGitHubService) SetStrategy(ctx context.Context, strategy string) error
- func (m *MockGitHubService) SetToken(ctx context.Context, token string) error
- func (m *MockGitHubService) UpdateRepositoryConfiguration(ctx context.Context, owner, repo string, config *github.RepositoryConfig) error
- func (m *MockGitHubService) ValidateForOperation(ctx context.Context, token, operation string) error
- func (m *MockGitHubService) ValidateForRepository(ctx context.Context, token, owner, repo string) error
- func (m *MockGitHubService) ValidateToken(ctx context.Context, token string) (*github.TokenInfoRecord, error)
- type MockGitHubServiceMockRecorder
- func (mr *MockGitHubServiceMockRecorder) CloneOrganization(ctx, orgName, targetPath, strategy any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) CloneRepository(ctx, repo, targetPath, strategy any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) ConfirmBulkOperation(ctx, operations any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) ConfirmOperation(ctx, prompt any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetDefaultBranch(ctx, owner, repo any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetOperationHistory(ctx, filters any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetRateLimit(ctx any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetRepository(ctx, owner, repo any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetRepositoryConfiguration(ctx, owner, repo any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetRequiredScopes(ctx, operation any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) GetSupportedStrategies(ctx any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) ListOrganizationRepositories(ctx, org any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) LogOperation(ctx, operation any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) RefreshAll(ctx, targetPath, orgName, strategy any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) SetConfirmationMode(ctx, mode any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) SetLogLevel(ctx, level any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) SetStrategy(ctx, strategy any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) SetToken(ctx, token any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) UpdateRepositoryConfiguration(ctx, owner, repo, config any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) ValidateForOperation(ctx, token, operation any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) ValidateForRepository(ctx, token, owner, repo any) *gomock.Call
- func (mr *MockGitHubServiceMockRecorder) ValidateToken(ctx, token any) *gomock.Call
- type MockHTTPClient
- func (m *MockHTTPClient) Delete(ctx context.Context, url string) (*http.Response, error)
- func (m *MockHTTPClient) Do(ctx context.Context, req *http.Request) (*http.Response, error)
- func (m *MockHTTPClient) EXPECT() *MockHTTPClientMockRecorder
- func (m *MockHTTPClient) Get(ctx context.Context, url string) (*http.Response, error)
- func (m *MockHTTPClient) Patch(ctx context.Context, url, contentType string, body io.Reader) (*http.Response, error)
- func (m *MockHTTPClient) Post(ctx context.Context, url, contentType string, body io.Reader) (*http.Response, error)
- func (m *MockHTTPClient) Put(ctx context.Context, url, contentType string, body io.Reader) (*http.Response, error)
- type MockHTTPClientMockRecorder
- func (mr *MockHTTPClientMockRecorder) Delete(ctx, url any) *gomock.Call
- func (mr *MockHTTPClientMockRecorder) Do(ctx, req any) *gomock.Call
- func (mr *MockHTTPClientMockRecorder) Get(ctx, url any) *gomock.Call
- func (mr *MockHTTPClientMockRecorder) Patch(ctx, url, contentType, body any) *gomock.Call
- func (mr *MockHTTPClientMockRecorder) Post(ctx, url, contentType, body any) *gomock.Call
- func (mr *MockHTTPClientMockRecorder) Put(ctx, url, contentType, body any) *gomock.Call
- type MockTokenValidatorInterface
- func (m *MockTokenValidatorInterface) EXPECT() *MockTokenValidatorInterfaceMockRecorder
- func (m *MockTokenValidatorInterface) GetRequiredScopes(ctx context.Context, operation string) ([]string, error)
- func (m *MockTokenValidatorInterface) ValidateForOperation(ctx context.Context, token, operation string) error
- func (m *MockTokenValidatorInterface) ValidateForRepository(ctx context.Context, token, owner, repo string) error
- func (m *MockTokenValidatorInterface) ValidateToken(ctx context.Context, token string) (*github.TokenInfoRecord, error)
- type MockTokenValidatorInterfaceMockRecorder
- func (mr *MockTokenValidatorInterfaceMockRecorder) GetRequiredScopes(ctx, operation any) *gomock.Call
- func (mr *MockTokenValidatorInterfaceMockRecorder) ValidateForOperation(ctx, token, operation any) *gomock.Call
- func (mr *MockTokenValidatorInterfaceMockRecorder) ValidateForRepository(ctx, token, owner, repo any) *gomock.Call
- func (mr *MockTokenValidatorInterfaceMockRecorder) ValidateToken(ctx, token any) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockAPIClient ¶
type MockAPIClient struct {
// contains filtered or unexported fields
}
MockAPIClient is a mock of APIClient interface.
func NewMockAPIClient ¶
func NewMockAPIClient(ctrl *gomock.Controller) *MockAPIClient
NewMockAPIClient creates a new mock instance.
func (*MockAPIClient) EXPECT ¶
func (m *MockAPIClient) EXPECT() *MockAPIClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockAPIClient) GetDefaultBranch ¶
GetDefaultBranch mocks base method.
func (*MockAPIClient) GetRateLimit ¶
GetRateLimit mocks base method.
func (*MockAPIClient) GetRepository ¶
func (m *MockAPIClient) GetRepository(ctx context.Context, owner, repo string) (*github.RepositoryInfo, error)
GetRepository mocks base method.
func (*MockAPIClient) GetRepositoryConfiguration ¶
func (m *MockAPIClient) GetRepositoryConfiguration(ctx context.Context, owner, repo string) (*github.RepositoryConfig, error)
GetRepositoryConfiguration mocks base method.
func (*MockAPIClient) ListOrganizationRepositories ¶
func (m *MockAPIClient) ListOrganizationRepositories(ctx context.Context, org string) ([]github.RepositoryInfo, error)
ListOrganizationRepositories mocks base method.
func (*MockAPIClient) SetToken ¶
func (m *MockAPIClient) SetToken(ctx context.Context, token string) error
SetToken mocks base method.
func (*MockAPIClient) UpdateRepositoryConfiguration ¶
func (m *MockAPIClient) UpdateRepositoryConfiguration(ctx context.Context, owner, repo string, config *github.RepositoryConfig) error
UpdateRepositoryConfiguration mocks base method.
type MockAPIClientMockRecorder ¶
type MockAPIClientMockRecorder struct {
// contains filtered or unexported fields
}
MockAPIClientMockRecorder is the mock recorder for MockAPIClient.
func (*MockAPIClientMockRecorder) GetDefaultBranch ¶
func (mr *MockAPIClientMockRecorder) GetDefaultBranch(ctx, owner, repo any) *gomock.Call
GetDefaultBranch indicates an expected call of GetDefaultBranch.
func (*MockAPIClientMockRecorder) GetRateLimit ¶
func (mr *MockAPIClientMockRecorder) GetRateLimit(ctx any) *gomock.Call
GetRateLimit indicates an expected call of GetRateLimit.
func (*MockAPIClientMockRecorder) GetRepository ¶
func (mr *MockAPIClientMockRecorder) GetRepository(ctx, owner, repo any) *gomock.Call
GetRepository indicates an expected call of GetRepository.
func (*MockAPIClientMockRecorder) GetRepositoryConfiguration ¶
func (mr *MockAPIClientMockRecorder) GetRepositoryConfiguration(ctx, owner, repo any) *gomock.Call
GetRepositoryConfiguration indicates an expected call of GetRepositoryConfiguration.
func (*MockAPIClientMockRecorder) ListOrganizationRepositories ¶
func (mr *MockAPIClientMockRecorder) ListOrganizationRepositories(ctx, org any) *gomock.Call
ListOrganizationRepositories indicates an expected call of ListOrganizationRepositories.
func (*MockAPIClientMockRecorder) SetToken ¶
func (mr *MockAPIClientMockRecorder) SetToken(ctx, token any) *gomock.Call
SetToken indicates an expected call of SetToken.
func (*MockAPIClientMockRecorder) UpdateRepositoryConfiguration ¶
func (mr *MockAPIClientMockRecorder) UpdateRepositoryConfiguration(ctx, owner, repo, config any) *gomock.Call
UpdateRepositoryConfiguration indicates an expected call of UpdateRepositoryConfiguration.
type MockChangeLoggerInterface ¶
type MockChangeLoggerInterface struct {
// contains filtered or unexported fields
}
MockChangeLoggerInterface is a mock of ChangeLoggerInterface interface.
func NewMockChangeLoggerInterface ¶
func NewMockChangeLoggerInterface(ctrl *gomock.Controller) *MockChangeLoggerInterface
NewMockChangeLoggerInterface creates a new mock instance.
func (*MockChangeLoggerInterface) EXPECT ¶
func (m *MockChangeLoggerInterface) EXPECT() *MockChangeLoggerInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockChangeLoggerInterface) GetOperationHistory ¶
func (m *MockChangeLoggerInterface) GetOperationHistory(ctx context.Context, filters github.LogFilters) ([]github.LogOperationRecord, error)
GetOperationHistory mocks base method.
func (*MockChangeLoggerInterface) LogOperation ¶
func (m *MockChangeLoggerInterface) LogOperation(ctx context.Context, operation github.LogOperationRecord) error
LogOperation mocks base method.
func (*MockChangeLoggerInterface) SetLogLevel ¶
func (m *MockChangeLoggerInterface) SetLogLevel(ctx context.Context, level github.LogLevelType) error
SetLogLevel mocks base method.
type MockChangeLoggerInterfaceMockRecorder ¶
type MockChangeLoggerInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockChangeLoggerInterfaceMockRecorder is the mock recorder for MockChangeLoggerInterface.
func (*MockChangeLoggerInterfaceMockRecorder) GetOperationHistory ¶
func (mr *MockChangeLoggerInterfaceMockRecorder) GetOperationHistory(ctx, filters any) *gomock.Call
GetOperationHistory indicates an expected call of GetOperationHistory.
func (*MockChangeLoggerInterfaceMockRecorder) LogOperation ¶
func (mr *MockChangeLoggerInterfaceMockRecorder) LogOperation(ctx, operation any) *gomock.Call
LogOperation indicates an expected call of LogOperation.
func (*MockChangeLoggerInterfaceMockRecorder) SetLogLevel ¶
func (mr *MockChangeLoggerInterfaceMockRecorder) SetLogLevel(ctx, level any) *gomock.Call
SetLogLevel indicates an expected call of SetLogLevel.
type MockCloneService ¶
type MockCloneService struct {
// contains filtered or unexported fields
}
MockCloneService is a mock of CloneService interface.
func NewMockCloneService ¶
func NewMockCloneService(ctrl *gomock.Controller) *MockCloneService
NewMockCloneService creates a new mock instance.
func (*MockCloneService) CloneOrganization ¶
func (m *MockCloneService) CloneOrganization(ctx context.Context, orgName, targetPath, strategy string) error
CloneOrganization mocks base method.
func (*MockCloneService) CloneRepository ¶
func (m *MockCloneService) CloneRepository(ctx context.Context, repo github.RepositoryInfo, targetPath, strategy string) error
CloneRepository mocks base method.
func (*MockCloneService) EXPECT ¶
func (m *MockCloneService) EXPECT() *MockCloneServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockCloneService) GetSupportedStrategies ¶
func (m *MockCloneService) GetSupportedStrategies(ctx context.Context) ([]string, error)
GetSupportedStrategies mocks base method.
func (*MockCloneService) RefreshAll ¶
func (m *MockCloneService) RefreshAll(ctx context.Context, targetPath, orgName, strategy string) error
RefreshAll mocks base method.
func (*MockCloneService) SetStrategy ¶
func (m *MockCloneService) SetStrategy(ctx context.Context, strategy string) error
SetStrategy mocks base method.
type MockCloneServiceMockRecorder ¶
type MockCloneServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockCloneServiceMockRecorder is the mock recorder for MockCloneService.
func (*MockCloneServiceMockRecorder) CloneOrganization ¶
func (mr *MockCloneServiceMockRecorder) CloneOrganization(ctx, orgName, targetPath, strategy any) *gomock.Call
CloneOrganization indicates an expected call of CloneOrganization.
func (*MockCloneServiceMockRecorder) CloneRepository ¶
func (mr *MockCloneServiceMockRecorder) CloneRepository(ctx, repo, targetPath, strategy any) *gomock.Call
CloneRepository indicates an expected call of CloneRepository.
func (*MockCloneServiceMockRecorder) GetSupportedStrategies ¶
func (mr *MockCloneServiceMockRecorder) GetSupportedStrategies(ctx any) *gomock.Call
GetSupportedStrategies indicates an expected call of GetSupportedStrategies.
func (*MockCloneServiceMockRecorder) RefreshAll ¶
func (mr *MockCloneServiceMockRecorder) RefreshAll(ctx, targetPath, orgName, strategy any) *gomock.Call
RefreshAll indicates an expected call of RefreshAll.
func (*MockCloneServiceMockRecorder) SetStrategy ¶
func (mr *MockCloneServiceMockRecorder) SetStrategy(ctx, strategy any) *gomock.Call
SetStrategy indicates an expected call of SetStrategy.
type MockConfirmationServiceInterface ¶
type MockConfirmationServiceInterface struct {
// contains filtered or unexported fields
}
MockConfirmationServiceInterface is a mock of ConfirmationServiceInterface interface.
func NewMockConfirmationServiceInterface ¶
func NewMockConfirmationServiceInterface(ctrl *gomock.Controller) *MockConfirmationServiceInterface
NewMockConfirmationServiceInterface creates a new mock instance.
func (*MockConfirmationServiceInterface) ConfirmBulkOperation ¶
func (m *MockConfirmationServiceInterface) ConfirmBulkOperation(ctx context.Context, operations []github.OperationRecord) ([]bool, error)
ConfirmBulkOperation mocks base method.
func (*MockConfirmationServiceInterface) ConfirmOperation ¶
func (m *MockConfirmationServiceInterface) ConfirmOperation(ctx context.Context, prompt *github.ConfirmationPromptRecord) (bool, error)
ConfirmOperation mocks base method.
func (*MockConfirmationServiceInterface) EXPECT ¶
func (m *MockConfirmationServiceInterface) EXPECT() *MockConfirmationServiceInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockConfirmationServiceInterface) SetConfirmationMode ¶
func (m *MockConfirmationServiceInterface) SetConfirmationMode(ctx context.Context, mode github.ConfirmationModeType) error
SetConfirmationMode mocks base method.
type MockConfirmationServiceInterfaceMockRecorder ¶
type MockConfirmationServiceInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockConfirmationServiceInterfaceMockRecorder is the mock recorder for MockConfirmationServiceInterface.
func (*MockConfirmationServiceInterfaceMockRecorder) ConfirmBulkOperation ¶
func (mr *MockConfirmationServiceInterfaceMockRecorder) ConfirmBulkOperation(ctx, operations any) *gomock.Call
ConfirmBulkOperation indicates an expected call of ConfirmBulkOperation.
func (*MockConfirmationServiceInterfaceMockRecorder) ConfirmOperation ¶
func (mr *MockConfirmationServiceInterfaceMockRecorder) ConfirmOperation(ctx, prompt any) *gomock.Call
ConfirmOperation indicates an expected call of ConfirmOperation.
func (*MockConfirmationServiceInterfaceMockRecorder) SetConfirmationMode ¶
func (mr *MockConfirmationServiceInterfaceMockRecorder) SetConfirmationMode(ctx, mode any) *gomock.Call
SetConfirmationMode indicates an expected call of SetConfirmationMode.
type MockGitHubService ¶
type MockGitHubService struct {
// contains filtered or unexported fields
}
MockGitHubService is a mock of GitHubService interface.
func NewMockGitHubService ¶
func NewMockGitHubService(ctrl *gomock.Controller) *MockGitHubService
NewMockGitHubService creates a new mock instance.
func (*MockGitHubService) CloneOrganization ¶
func (m *MockGitHubService) CloneOrganization(ctx context.Context, orgName, targetPath, strategy string) error
CloneOrganization mocks base method.
func (*MockGitHubService) CloneRepository ¶
func (m *MockGitHubService) CloneRepository(ctx context.Context, repo github.RepositoryInfo, targetPath, strategy string) error
CloneRepository mocks base method.
func (*MockGitHubService) ConfirmBulkOperation ¶
func (m *MockGitHubService) ConfirmBulkOperation(ctx context.Context, operations []github.OperationRecord) ([]bool, error)
ConfirmBulkOperation mocks base method.
func (*MockGitHubService) ConfirmOperation ¶
func (m *MockGitHubService) ConfirmOperation(ctx context.Context, prompt *github.ConfirmationPromptRecord) (bool, error)
ConfirmOperation mocks base method.
func (*MockGitHubService) EXPECT ¶
func (m *MockGitHubService) EXPECT() *MockGitHubServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockGitHubService) GetDefaultBranch ¶
func (m *MockGitHubService) GetDefaultBranch(ctx context.Context, owner, repo string) (string, error)
GetDefaultBranch mocks base method.
func (*MockGitHubService) GetOperationHistory ¶
func (m *MockGitHubService) GetOperationHistory(ctx context.Context, filters github.LogFilters) ([]github.LogOperationRecord, error)
GetOperationHistory mocks base method.
func (*MockGitHubService) GetRateLimit ¶
GetRateLimit mocks base method.
func (*MockGitHubService) GetRepository ¶
func (m *MockGitHubService) GetRepository(ctx context.Context, owner, repo string) (*github.RepositoryInfo, error)
GetRepository mocks base method.
func (*MockGitHubService) GetRepositoryConfiguration ¶
func (m *MockGitHubService) GetRepositoryConfiguration(ctx context.Context, owner, repo string) (*github.RepositoryConfig, error)
GetRepositoryConfiguration mocks base method.
func (*MockGitHubService) GetRequiredScopes ¶
func (m *MockGitHubService) GetRequiredScopes(ctx context.Context, operation string) ([]string, error)
GetRequiredScopes mocks base method.
func (*MockGitHubService) GetSupportedStrategies ¶
func (m *MockGitHubService) GetSupportedStrategies(ctx context.Context) ([]string, error)
GetSupportedStrategies mocks base method.
func (*MockGitHubService) ListOrganizationRepositories ¶
func (m *MockGitHubService) ListOrganizationRepositories(ctx context.Context, org string) ([]github.RepositoryInfo, error)
ListOrganizationRepositories mocks base method.
func (*MockGitHubService) LogOperation ¶
func (m *MockGitHubService) LogOperation(ctx context.Context, operation github.LogOperationRecord) error
LogOperation mocks base method.
func (*MockGitHubService) RefreshAll ¶
func (m *MockGitHubService) RefreshAll(ctx context.Context, targetPath, orgName, strategy string) error
RefreshAll mocks base method.
func (*MockGitHubService) SetConfirmationMode ¶
func (m *MockGitHubService) SetConfirmationMode(ctx context.Context, mode github.ConfirmationModeType) error
SetConfirmationMode mocks base method.
func (*MockGitHubService) SetLogLevel ¶
func (m *MockGitHubService) SetLogLevel(ctx context.Context, level github.LogLevelType) error
SetLogLevel mocks base method.
func (*MockGitHubService) SetStrategy ¶
func (m *MockGitHubService) SetStrategy(ctx context.Context, strategy string) error
SetStrategy mocks base method.
func (*MockGitHubService) SetToken ¶
func (m *MockGitHubService) SetToken(ctx context.Context, token string) error
SetToken mocks base method.
func (*MockGitHubService) UpdateRepositoryConfiguration ¶
func (m *MockGitHubService) UpdateRepositoryConfiguration(ctx context.Context, owner, repo string, config *github.RepositoryConfig) error
UpdateRepositoryConfiguration mocks base method.
func (*MockGitHubService) ValidateForOperation ¶
func (m *MockGitHubService) ValidateForOperation(ctx context.Context, token, operation string) error
ValidateForOperation mocks base method.
func (*MockGitHubService) ValidateForRepository ¶
func (m *MockGitHubService) ValidateForRepository(ctx context.Context, token, owner, repo string) error
ValidateForRepository mocks base method.
func (*MockGitHubService) ValidateToken ¶
func (m *MockGitHubService) ValidateToken(ctx context.Context, token string) (*github.TokenInfoRecord, error)
ValidateToken mocks base method.
type MockGitHubServiceMockRecorder ¶
type MockGitHubServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockGitHubServiceMockRecorder is the mock recorder for MockGitHubService.
func (*MockGitHubServiceMockRecorder) CloneOrganization ¶
func (mr *MockGitHubServiceMockRecorder) CloneOrganization(ctx, orgName, targetPath, strategy any) *gomock.Call
CloneOrganization indicates an expected call of CloneOrganization.
func (*MockGitHubServiceMockRecorder) CloneRepository ¶
func (mr *MockGitHubServiceMockRecorder) CloneRepository(ctx, repo, targetPath, strategy any) *gomock.Call
CloneRepository indicates an expected call of CloneRepository.
func (*MockGitHubServiceMockRecorder) ConfirmBulkOperation ¶
func (mr *MockGitHubServiceMockRecorder) ConfirmBulkOperation(ctx, operations any) *gomock.Call
ConfirmBulkOperation indicates an expected call of ConfirmBulkOperation.
func (*MockGitHubServiceMockRecorder) ConfirmOperation ¶
func (mr *MockGitHubServiceMockRecorder) ConfirmOperation(ctx, prompt any) *gomock.Call
ConfirmOperation indicates an expected call of ConfirmOperation.
func (*MockGitHubServiceMockRecorder) GetDefaultBranch ¶
func (mr *MockGitHubServiceMockRecorder) GetDefaultBranch(ctx, owner, repo any) *gomock.Call
GetDefaultBranch indicates an expected call of GetDefaultBranch.
func (*MockGitHubServiceMockRecorder) GetOperationHistory ¶
func (mr *MockGitHubServiceMockRecorder) GetOperationHistory(ctx, filters any) *gomock.Call
GetOperationHistory indicates an expected call of GetOperationHistory.
func (*MockGitHubServiceMockRecorder) GetRateLimit ¶
func (mr *MockGitHubServiceMockRecorder) GetRateLimit(ctx any) *gomock.Call
GetRateLimit indicates an expected call of GetRateLimit.
func (*MockGitHubServiceMockRecorder) GetRepository ¶
func (mr *MockGitHubServiceMockRecorder) GetRepository(ctx, owner, repo any) *gomock.Call
GetRepository indicates an expected call of GetRepository.
func (*MockGitHubServiceMockRecorder) GetRepositoryConfiguration ¶
func (mr *MockGitHubServiceMockRecorder) GetRepositoryConfiguration(ctx, owner, repo any) *gomock.Call
GetRepositoryConfiguration indicates an expected call of GetRepositoryConfiguration.
func (*MockGitHubServiceMockRecorder) GetRequiredScopes ¶
func (mr *MockGitHubServiceMockRecorder) GetRequiredScopes(ctx, operation any) *gomock.Call
GetRequiredScopes indicates an expected call of GetRequiredScopes.
func (*MockGitHubServiceMockRecorder) GetSupportedStrategies ¶
func (mr *MockGitHubServiceMockRecorder) GetSupportedStrategies(ctx any) *gomock.Call
GetSupportedStrategies indicates an expected call of GetSupportedStrategies.
func (*MockGitHubServiceMockRecorder) ListOrganizationRepositories ¶
func (mr *MockGitHubServiceMockRecorder) ListOrganizationRepositories(ctx, org any) *gomock.Call
ListOrganizationRepositories indicates an expected call of ListOrganizationRepositories.
func (*MockGitHubServiceMockRecorder) LogOperation ¶
func (mr *MockGitHubServiceMockRecorder) LogOperation(ctx, operation any) *gomock.Call
LogOperation indicates an expected call of LogOperation.
func (*MockGitHubServiceMockRecorder) RefreshAll ¶
func (mr *MockGitHubServiceMockRecorder) RefreshAll(ctx, targetPath, orgName, strategy any) *gomock.Call
RefreshAll indicates an expected call of RefreshAll.
func (*MockGitHubServiceMockRecorder) SetConfirmationMode ¶
func (mr *MockGitHubServiceMockRecorder) SetConfirmationMode(ctx, mode any) *gomock.Call
SetConfirmationMode indicates an expected call of SetConfirmationMode.
func (*MockGitHubServiceMockRecorder) SetLogLevel ¶
func (mr *MockGitHubServiceMockRecorder) SetLogLevel(ctx, level any) *gomock.Call
SetLogLevel indicates an expected call of SetLogLevel.
func (*MockGitHubServiceMockRecorder) SetStrategy ¶
func (mr *MockGitHubServiceMockRecorder) SetStrategy(ctx, strategy any) *gomock.Call
SetStrategy indicates an expected call of SetStrategy.
func (*MockGitHubServiceMockRecorder) SetToken ¶
func (mr *MockGitHubServiceMockRecorder) SetToken(ctx, token any) *gomock.Call
SetToken indicates an expected call of SetToken.
func (*MockGitHubServiceMockRecorder) UpdateRepositoryConfiguration ¶
func (mr *MockGitHubServiceMockRecorder) UpdateRepositoryConfiguration(ctx, owner, repo, config any) *gomock.Call
UpdateRepositoryConfiguration indicates an expected call of UpdateRepositoryConfiguration.
func (*MockGitHubServiceMockRecorder) ValidateForOperation ¶
func (mr *MockGitHubServiceMockRecorder) ValidateForOperation(ctx, token, operation any) *gomock.Call
ValidateForOperation indicates an expected call of ValidateForOperation.
func (*MockGitHubServiceMockRecorder) ValidateForRepository ¶
func (mr *MockGitHubServiceMockRecorder) ValidateForRepository(ctx, token, owner, repo any) *gomock.Call
ValidateForRepository indicates an expected call of ValidateForRepository.
func (*MockGitHubServiceMockRecorder) ValidateToken ¶
func (mr *MockGitHubServiceMockRecorder) ValidateToken(ctx, token any) *gomock.Call
ValidateToken indicates an expected call of ValidateToken.
type MockHTTPClient ¶
type MockHTTPClient struct {
// contains filtered or unexported fields
}
MockHTTPClient is a mock of HTTPClient interface.
func NewMockHTTPClient ¶
func NewMockHTTPClient(ctrl *gomock.Controller) *MockHTTPClient
NewMockHTTPClient creates a new mock instance.
func (*MockHTTPClient) EXPECT ¶
func (m *MockHTTPClient) EXPECT() *MockHTTPClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockHTTPClient) Patch ¶
func (m *MockHTTPClient) Patch(ctx context.Context, url, contentType string, body io.Reader) (*http.Response, error)
Patch mocks base method.
type MockHTTPClientMockRecorder ¶
type MockHTTPClientMockRecorder struct {
// contains filtered or unexported fields
}
MockHTTPClientMockRecorder is the mock recorder for MockHTTPClient.
func (*MockHTTPClientMockRecorder) Delete ¶
func (mr *MockHTTPClientMockRecorder) Delete(ctx, url any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockHTTPClientMockRecorder) Do ¶
func (mr *MockHTTPClientMockRecorder) Do(ctx, req any) *gomock.Call
Do indicates an expected call of Do.
func (*MockHTTPClientMockRecorder) Get ¶
func (mr *MockHTTPClientMockRecorder) Get(ctx, url any) *gomock.Call
Get indicates an expected call of Get.
func (*MockHTTPClientMockRecorder) Patch ¶
func (mr *MockHTTPClientMockRecorder) Patch(ctx, url, contentType, body any) *gomock.Call
Patch indicates an expected call of Patch.
type MockTokenValidatorInterface ¶
type MockTokenValidatorInterface struct {
// contains filtered or unexported fields
}
MockTokenValidatorInterface is a mock of TokenValidatorInterface interface.
func NewMockTokenValidatorInterface ¶
func NewMockTokenValidatorInterface(ctrl *gomock.Controller) *MockTokenValidatorInterface
NewMockTokenValidatorInterface creates a new mock instance.
func (*MockTokenValidatorInterface) EXPECT ¶
func (m *MockTokenValidatorInterface) EXPECT() *MockTokenValidatorInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockTokenValidatorInterface) GetRequiredScopes ¶
func (m *MockTokenValidatorInterface) GetRequiredScopes(ctx context.Context, operation string) ([]string, error)
GetRequiredScopes mocks base method.
func (*MockTokenValidatorInterface) ValidateForOperation ¶
func (m *MockTokenValidatorInterface) ValidateForOperation(ctx context.Context, token, operation string) error
ValidateForOperation mocks base method.
func (*MockTokenValidatorInterface) ValidateForRepository ¶
func (m *MockTokenValidatorInterface) ValidateForRepository(ctx context.Context, token, owner, repo string) error
ValidateForRepository mocks base method.
func (*MockTokenValidatorInterface) ValidateToken ¶
func (m *MockTokenValidatorInterface) ValidateToken(ctx context.Context, token string) (*github.TokenInfoRecord, error)
ValidateToken mocks base method.
type MockTokenValidatorInterfaceMockRecorder ¶
type MockTokenValidatorInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockTokenValidatorInterfaceMockRecorder is the mock recorder for MockTokenValidatorInterface.
func (*MockTokenValidatorInterfaceMockRecorder) GetRequiredScopes ¶
func (mr *MockTokenValidatorInterfaceMockRecorder) GetRequiredScopes(ctx, operation any) *gomock.Call
GetRequiredScopes indicates an expected call of GetRequiredScopes.
func (*MockTokenValidatorInterfaceMockRecorder) ValidateForOperation ¶
func (mr *MockTokenValidatorInterfaceMockRecorder) ValidateForOperation(ctx, token, operation any) *gomock.Call
ValidateForOperation indicates an expected call of ValidateForOperation.
func (*MockTokenValidatorInterfaceMockRecorder) ValidateForRepository ¶
func (mr *MockTokenValidatorInterfaceMockRecorder) ValidateForRepository(ctx, token, owner, repo any) *gomock.Call
ValidateForRepository indicates an expected call of ValidateForRepository.
func (*MockTokenValidatorInterfaceMockRecorder) ValidateToken ¶
func (mr *MockTokenValidatorInterfaceMockRecorder) ValidateToken(ctx, token any) *gomock.Call
ValidateToken indicates an expected call of ValidateToken.